==> vtk6-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkIncrementalOctreeNode.java <==
// java wrapper for vtkIncrementalOctreeNode object
//

package vtk;
import vtk.*;

public class vtkIncrementalOctreeNode extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetNumberOfPoints_2();
  public int GetNumberOfPoints()
    { return GetNumberOfPoints_2(); }

  private native long GetPointIdSet_3();
  public vtkIdList GetPointIdSet() {
    long temp = GetPointIdSet_3();

    if (temp == 0) return null;
    return (vtkIdList)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void DeleteChildNodes_4();
  public void DeleteChildNodes()
    { DeleteChildNodes_4(); }

  private native void SetBounds_5(double id0,double id1,double id2,double id3,double id4,double id5);
  public void SetBounds(double id0,double id1,double id2,double id3,double id4,double id5)
    { SetBounds_5(id0,id1,id2,id3,id4,id5); }

  private native void GetBounds_6(double id0[]);
  public void GetBounds(double id0[])
    { GetBounds_6(id0); }

  private native double[] GetMinBounds_7();
  public double[] GetMinBounds()
    { return GetMinBounds_7(); }

  private native double[] GetMaxBounds_8();
  public double[] GetMaxBounds()
    { return GetMaxBounds_8(); }

  private native int IsLeaf_9();
  public int IsLeaf()
    { return IsLeaf_9(); }

  private native int GetChildIndex_10(double id0[]);
  public int GetChildIndex(double id0[])
    { return GetChildIndex_10(id0); }

  private native long GetChild_11(int id0);
  public vtkIncrementalOctreeNode GetChild(int id0) {
    long temp = GetChild_11(id0);

    if (temp == 0) return null;
    return (vtkIncrementalOctreeNode)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native int ContainsPoint_12(double id0[]);
  public int ContainsPoint(double id0[])
    { return ContainsPoint_12(id0); }

  private native int ContainsPointByData_13(double id0[]);
  public int ContainsPointByData(double id0[])
    { return ContainsPointByData_13(id0); }

  private native double GetDistance2ToInnerBoundary_14(double id0[],vtkIncrementalOctreeNode id1);
  public double GetDistance2ToInnerBoundary(double id0[],vtkIncrementalOctreeNode id1)
    { return GetDistance2ToInnerBoundary_14(id0,id1); }

  private native double GetDistance2ToBoundary_15(double id0[],vtkIncrementalOctreeNode id1,int id2);
  public double GetDistance2ToBoundary(double id0[],vtkIncrementalOctreeNode id1,int id2)
    { return GetDistance2ToBoundary_15(id0,id1,id2); }

  private native double GetDistance2ToBoundary_16(double id0[],double id1[],vtkIncrementalOctreeNode id2,int id3);
  public double GetDistance2ToBoundary(double id0[],double id1[],vtkIncrementalOctreeNode id2,int id3)
    { return GetDistance2ToBoundary_16(id0,id1,id2,id3); }

  private native void ExportAllPointIdsByInsertion_17(vtkIdList id0);
  public void ExportAllPointIdsByInsertion(vtkIdList id0)
    { ExportAllPointIdsByInsertion_17(id0); }

  public vtkIncrementalOctreeNode() { super(); }

  public vtkIncrementalOctreeNode(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-20-armv6h.pkg.tar.xz: vtk/vtkIncrementalOctreeNode.java <==
// java wrapper for vtkIncrementalOctreeNode object
//

package vtk;
import vtk.*;

public class vtkIncrementalOctreeNode extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetNumberOfPoints_2();
  public int GetNumberOfPoints()
    { return GetNumberOfPoints_2(); }

  private native long GetPointIdSet_3();
  public vtkIdList GetPointIdSet() {
    long temp = GetPointIdSet_3();

    if (temp == 0) return null;
    return (vtkIdList)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void DeleteChildNodes_4();
  public void DeleteChildNodes()
    { DeleteChildNodes_4(); }

  private native void SetBounds_5(double id0,double id1,double id2,double id3,double id4,double id5);
  public void SetBounds(double id0,double id1,double id2,double id3,double id4,double id5)
    { SetBounds_5(id0,id1,id2,id3,id4,id5); }

  private native void GetBounds_6(double id0[]);
  public void GetBounds(double id0[])
    { GetBounds_6(id0); }

  private native double[] GetMinBounds_7();
  public double[] GetMinBounds()
    { return GetMinBounds_7(); }

  private native double[] GetMaxBounds_8();
  public double[] GetMaxBounds()
    { return GetMaxBounds_8(); }

  private native int IsLeaf_9();
  public int IsLeaf()
    { return IsLeaf_9(); }

  private native int GetChildIndex_10(double id0[]);
  public int GetChildIndex(double id0[])
    { return GetChildIndex_10(id0); }

  private native long GetChild_11(int id0);
  public vtkIncrementalOctreeNode GetChild(int id0) {
    long temp = GetChild_11(id0);

    if (temp == 0) return null;
    return (vtkIncrementalOctreeNode)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int ContainsPoint_12(double id0[]);
  public int ContainsPoint(double id0[])
    { return ContainsPoint_12(id0); }

  private native int ContainsPointByData_13(double id0[]);
  public int ContainsPointByData(double id0[])
    { return ContainsPointByData_13(id0); }

  private native double GetDistance2ToInnerBoundary_14(double id0[],vtkIncrementalOctreeNode id1);
  public double GetDistance2ToInnerBoundary(double id0[],vtkIncrementalOctreeNode id1)
    { return GetDistance2ToInnerBoundary_14(id0,id1); }

  private native double GetDistance2ToBoundary_15(double id0[],vtkIncrementalOctreeNode id1,int id2);
  public double GetDistance2ToBoundary(double id0[],vtkIncrementalOctreeNode id1,int id2)
    { return GetDistance2ToBoundary_15(id0,id1,id2); }

  private native double GetDistance2ToBoundary_16(double id0[],double id1[],vtkIncrementalOctreeNode id2,int id3);
  public double GetDistance2ToBoundary(double id0[],double id1[],vtkIncrementalOctreeNode id2,int id3)
    { return GetDistance2ToBoundary_16(id0,id1,id2,id3); }

  private native void ExportAllPointIdsByInsertion_17(vtkIdList id0);
  public void ExportAllPointIdsByInsertion(vtkIdList id0)
    { ExportAllPointIdsByInsertion_17(id0); }

  public vtkIncrementalOctreeNode() { super(); }

  public vtkIncrementalOctreeNode(long id) { super(id); }
  public native long   VTKInit();

}
